@@ -8,10 +8,10 @@ from .pycm_interpret import *
 
 def sensitivity_index_calc(TPR, FPR):
     """
-    Calculate sensitivity index (d prime).
+    Calculate Sensitivity index (d prime).
 
     :param TPR: sensitivity, recall, hit rate, or true positive rate
-    :type TPR : float
+    :type TPR: float
     :param FPR: fall-out or false positive rate
     :type FPR: float
     :return: sensitivity index as float
@@ -24,14 +24,14 @@ def sensitivity_index_calc(TPR, FPR):
 
 def NB_calc(TP, FP, POP, w):
     """
-    Calculate NB (Net Benefit).
+    Calculate Net Benefit (NB).
 
     :param TP: true positive
-    :type TP : int
+    :type TP: int
     :param FP: false positive
-    :type FP : int
-    :param POP: population
-    :type POP : int
+    :type FP: int
+    :param POP: population or total number of samples
+    :type POP: int
     :param w: weight
     :type w: float
     :return: NB as float
@@ -45,16 +45,16 @@ def NB_calc(TP, FP, POP, w):
 
 def TI_calc(TP, FP, FN, alpha, beta):
     """
-    Calculate TI (Tversky index).
+    Calculate Tversky index (TI).
 
     :param TP: true positive
-    :type TP : int
+    :type TP: int
     :param FP: false positive
-    :type FP : int
+    :type FP: int
     :param FN: false negative
-    :type FN : int
+    :type FN: int
     :param alpha: alpha coefficient
-    :type alpha : float
+    :type alpha: float
     :param beta: beta coefficient
     :type beta: float
     :return: TI as float
@@ -68,15 +68,15 @@ def TI_calc(TP, FP, FN, alpha, beta):
 
 def OOC_calc(TP, TOP, P):
     """
-    Calculate OOC (Otsuka-Ochiai coefficient).
+    Calculate Otsuka-Ochiai coefficient (OOC).
 
     :param TP: true positive
-    :type TP : int
-    :param TOP: test outcome positive
-    :type TOP : int
-    :param P:  condition positive
-    :type P : int
-    :return: Otsuka-Ochiai coefficient as float
+    :type TP: int
+    :param TOP: number of positives in predict vector
+    :type TOP: int
+    :param P: number of actual positives
+    :type P: int
+    :return: OOC as float
     """
     try:
         OOC = TP / (math.sqrt(TOP * P))
@@ -87,14 +87,14 @@ def OOC_calc(TP, TOP, P):
 
 def OC_calc(TP, TOP, P):
     """
-    Calculate OC (Overlap coefficient).
+    Calculate Overlap coefficient (OC).
 
     :param TP: true positive
-    :type TP : int
-    :param TOP: test outcome positive
-    :type TOP : int
-    :param P:  condition positive
-    :type P : int
+    :type TP: int
+    :param TOP: number of positives in predict vector
+    :type TOP: int
+    :param P: number of actual positives
+    :type P: int
     :return: overlap coefficient as float
     """
     try:
@@ -106,16 +106,16 @@ def OC_calc(TP, TOP, P):
 
 def AGF_calc(TP, FP, FN, TN):
     """
-    Calculate AGF (Adjusted F-score).
+    Calculate Adjusted F-score (AGF).
 
     :param TP: true positive
-    :type TP : int
+    :type TP: int
     :param TN: true negative
-    :type TN : int
+    :type TN: int
     :param FP: false positive
-    :type FP : int
+    :type FP: int
     :param FN: false negative
-    :type FN : int
+    :type FN: int
     :return: AGF as float
     """
     try:
@@ -129,18 +129,18 @@ def AGF_calc(TP, FP, FN, TN):
 
 def AGM_calc(TPR, TNR, GM, N, POP):
     """
-    Calculate AGM (Adjusted geometric mean).
+    Calculate Adjusted geometric mean (AGM).
 
     :param TNR: specificity or true negative rate
-    :type TNR : float
+    :type TNR: float
     :param TPR: sensitivity, recall, hit rate, or true positive rate
-    :type TPR : float
+    :type TPR: float
     :param GM: geometric mean
-    :type GM : float
-    :param N: condition negative
-    :type N : int
-    :param POP: population
-    :type POP : int
+    :type GM: float
+    :param N: number of actual negatives
+    :type N: int
+    :param POP: population or total number of samples
+    :type POP: int
     :return: AGM as float
     """
     try:
@@ -159,13 +159,13 @@ def Q_calc(TP, TN, FP, FN):
     Calculate Yule's Q.
 
     :param TP: true positive
-    :type TP : int
+    :type TP: int
     :param TN: true negative
-    :type TN : int
+    :type TN: int
     :param FP: false positive
-    :type FP : int
+    :type FP: int
     :param FN: false negative
-    :type FN : int
+    :type FN: int
     :return: Yule's Q as float
     """
     try:
@@ -178,10 +178,10 @@ def Q_calc(TP, TN, FP, FN):
 
 def TTPN_calc(item1, item2):
     """
-    Calculate TPR,TNR,PPV,NPV.
+    Calculate TPR, TNR, PPV, and NPV.
 
     :param item1: item1 in fractional expression
-    :type item1 : int
+    :type item1: int
     :param item2: item2 in fractional expression
     :type item2: int
     :return: result as float
@@ -195,7 +195,7 @@ def TTPN_calc(item1, item2):
 
 def FXR_calc(item):
     """
-    Calculate FNR,FPR,FDR,FOR.
+    Calculate False negative rate, False positive rate, False discovery rate (FDR), and False omission rate (FOR).
 
     :param item: item In expression
     :type item:float
@@ -210,16 +210,16 @@ def FXR_calc(item):
 
 def ACC_calc(TP, TN, FP, FN):
     """
-    Calculate accuracy.
+    Calculate Accuracy.
 
     :param TP: true positive
-    :type TP : int
+    :type TP: int
     :param TN: true negative
-    :type TN : int
+    :type TN: int
     :param FP: false positive
-    :type FP : int
+    :type FP: int
     :param FN: false negative
-    :type FN : int
+    :type FN: int
     :return: accuracy as float
     """
     try:
@@ -234,14 +234,14 @@ def F_calc(TP, FP, FN, beta):
     Calculate F-score.
 
     :param TP: true positive
-    :type TP : int
+    :type TP: int
     :param FP: false positive
-    :type FP : int
+    :type FP: int
     :param FN: false negative
-    :type FN : int
-    :param beta : beta coefficient
-    :type beta : float
-    :return: F score as float
+    :type FN: int
+    :param beta: beta coefficient
+    :type beta: float
+    :return: F-score as float
     """
     try:
         result = ((1 + (beta)**2) * TP) / \
@@ -253,16 +253,16 @@ def F_calc(TP, FP, FN, beta):
 
 def MCC_calc(TP, TN, FP, FN):
     """
-    Calculate MCC (Matthews correlation coefficient).
+    Calculate Matthews correlation coefficient (MCC).
 
     :param TP: true positive
-    :type TP : int
+    :type TP: int
     :param TN: true negative
-    :type TN : int
+    :type TN: int
     :param FP: false positive
-    :type FP : int
+    :type FP: int
     :param FN: false negative
-    :type FN : int
+    :type FN: int
     :return: MCC as float
     """
     try:
@@ -275,7 +275,7 @@ def MCC_calc(TP, TN, FP, FN):
 
 def MK_BM_calc(item1, item2):
     """
-    Calculate BM (Informedness) and MK (Markedness) and ICSI (Individual classification success index).
+    Calculate Informedness (BM), Markedness (MK), and Individual classification success index (ICSI).
 
     :param item1: item1 in expression
     :type item1:float
@@ -292,7 +292,7 @@ def MK_BM_calc(item1, item2):
 
 def LR_calc(item1, item2):
     """
-    Calculate likelihood ratio.
+    Calculate Likelihood ratio (LR).
 
     :param item1: item1 in expression
     :type item1:float
@@ -309,12 +309,12 @@ def LR_calc(item1, item2):
 
 def PRE_calc(P, POP):
     """
-    Calculate prevalence.
+    Calculate Prevalence.
 
-    :param P: condition positive
-    :type P : int
-    :param POP: population
-    :type POP : int
+    :param P: number of actual positives
+    :type P: int
+    :param POP: population or total number of samples
+    :type POP: int
     :return: prevalence as float
     """
     try:
@@ -328,10 +328,10 @@ def G_calc(item1, item2):
     """
     Calculate G-measure & G-mean.
 
-    :param item1: PPV or TPR or TNR
-    :type item1 : float
-    :param item2: PPV or TPR or TNR
-    :type item2 : float
+    :param item1: True positive rate (TPR) or True negative rate (TNR) or Positive predictive value (PPV)
+    :type item1: float
+    :param item2: True positive rate (TPR) or True negative rate (TNR) or Positive predictive value (PPV)
+    :type item2: float
     :return: G-measure or G-mean as float
     """
     try:
@@ -343,13 +343,13 @@ def G_calc(item1, item2):
 
 def RACC_calc(TOP, P, POP):
     """
-    Calculate random accuracy.
+    Calculate Random accuracy (RACC).
 
-    :param TOP: test outcome positive
-    :type TOP : int
-    :param P:  condition positive
-    :type P : int
-    :param POP: population
+    :param TOP: number of positives in predict vector
+    :type TOP: int
+    :param P: number of actual positives
+    :type P: int
+    :param POP: population or total number of samples
     :type POP:int
     :return: RACC as float
     """
@@ -362,14 +362,14 @@ def RACC_calc(TOP, P, POP):
 
 def RACCU_calc(TOP, P, POP):
     """
-    Calculate RACCU (Random accuracy unbiased).
+    Calculate Random accuracy unbiased (RACCU).
 
-    :param TOP: test outcome positive
-    :type TOP : int
-    :param P: condition positive
-    :type P : int
-    :param POP: population
-    :type POP : int
+    :param TOP: number of positives in predict vector
+    :type TOP: int
+    :param P: number of actual positives
+    :type P: int
+    :param POP: population or total number of samples
+    :type POP: int
     :return: RACCU as float
     """
     try:
@@ -381,7 +381,7 @@ def RACCU_calc(TOP, P, POP):
 
 def ERR_calc(ACC):
     """
-    Calculate error rate.
+    Calculate Error rate.
 
     :param ACC: accuracy
     :type ACC: float
@@ -398,11 +398,11 @@ def jaccard_index_calc(TP, TOP, P):
     Calculate Jaccard index for each class.
 
     :param TP: true positive
-    :type TP : int
-    :param TOP: test outcome positive
-    :type TOP : int
-    :param P:  condition positive
-    :type P : int
+    :type TP: int
+    :param TOP: number of positives in predict vector
+    :type TOP: int
+    :param P: number of actual positives
+    :type P: int
     :return: Jaccard index as float
     """
     try:
@@ -413,16 +413,16 @@ def jaccard_index_calc(TP, TOP, P):
 
 def IS_calc(TP, FP, FN, POP):
     """
-    Calculate IS (Information score).
+    Calculate Information score (IS).
 
     :param TP: true positive
-    :type TP : int
+    :type TP: int
     :param FP: false positive
-    :type FP : int
+    :type FP: int
     :param FN: false negative
-    :type FN : int
-    :param POP: population
-    :type POP : int
+    :type FN: int
+    :param POP: population or total number of samples
+    :type POP: int
     :return: IS as float
     """
     try:
@@ -442,23 +442,23 @@ def CEN_misclassification_calc(
         subject_class,
         modified=False):
     """
-    Calculate misclassification probability of classifying.
+    Calculate Misclassification probability.
 
-    :param table: input matrix
-    :type table : dict
-    :param TOP: test outcome positive
-    :type TOP : int
-    :param P: condition positive
-    :type P : int
+    :param table: input confusion matrix
+    :type table: dict
+    :param TOP: number of positives in predict vector
+    :type TOP: int
+    :param P: number of actual positives
+    :type P: int
     :param i: table row index (class name)
-    :type i : any valid type
+    :type i: any valid type
     :param j: table col index (class name)
-    :type j : any valid type
+    :type j: any valid type
     :param subject_class: subject to class (class name)
     :type subject_class: any valid type
-    :param modified : modified mode flag
-    :type modified : bool
-    :return: misclassification probability of classifying as float
+    :param modified: modified mode flag
+    :type modified: bool
+    :return: misclassification probability as float
     """
     try:
         result = TOP + P
@@ -472,21 +472,21 @@ def CEN_misclassification_calc(
 
 def CEN_calc(classes, table, TOP, P, class_name, modified=False):
     """
-    Calculate CEN (Confusion Entropy)/ MCEN(Modified Confusion Entropy).
+    Calculate Confusion Entropy (CEN) (or Modified Confusion Entropy (MCEN)).
 
-    :param classes: classes
-    :type classes : list
-    :param table: input matrix
-    :type table : dict
-    :param TOP: test outcome positive
-    :type TOP : int
-    :param P: condition positive
-    :type P : int
+    :param classes: confusion matrix classes
+    :type classes: list
+    :param table: input confusion matrix
+    :type table: dict
+    :param TOP: number of positives in predict vector
+    :type TOP: int
+    :param P: number of actual positives
+    :type P: int
     :param class_name: reviewed class name
-    :type class_name : any valid type
-    :param modified : modified mode flag
-    :type modified : bool
-    :return: CEN(MCEN) as float
+    :type class_name: any valid type
+    :param modified: modified mode flag
+    :type modified: bool
+    :return: CEN (or MCEN) as float
     """
     try:
         result = 0
@@ -510,12 +510,12 @@ def CEN_calc(classes, table, TOP, P, class_name, modified=False):
 
 def AUC_calc(item, TPR):
     """
-    Calculate AUC/AUPR (Area under the ROC/PR curve for each class).
+    Calculate Area under the ROC/PR curve for each class (AUC/AUPR).
 
-    :param item: TNR or PPV
-    :type item : float
+    :param item: True negative rate (TNR) or Positive predictive value (PPV)
+    :type item: float
     :param TPR: sensitivity, recall, hit rate, or true positive rate
-    :type TPR : float
+    :type TPR: float
     :return: AUC/AUPR as float
     """
     try:
@@ -526,12 +526,12 @@ def AUC_calc(item, TPR):
 
 def dInd_calc(TNR, TPR):
     """
-    Calculate dInd (Distance index).
+    Calculate Distance index (dInd).
 
     :param TNR: specificity or true negative rate
-    :type TNR : float
+    :type TNR: float
     :param TPR: sensitivity, recall, hit rate, or true positive rate
-    :type TPR : float
+    :type TPR: float
     :return: dInd as float
     """
     try:
@@ -543,10 +543,10 @@ def dInd_calc(TNR, TPR):
 
 def sInd_calc(dInd):
     """
-    Calculate sInd (Similarity index).
+    Calculate Similarity index (sInd).
 
     :param dInd: dInd
-    :type dInd : float
+    :type dInd: float
     :return: sInd as float
     """
     try:
@@ -557,12 +557,12 @@ def sInd_calc(dInd):
 
 def DP_calc(TPR, TNR):
     """
-    Calculate DP (Discriminant power).
+    Calculate Discriminant power (DP).
 
     :param TNR: specificity or true negative rate
-    :type TNR : float
+    :type TNR: float
     :param TPR: sensitivity, recall, hit rate, or true positive rate
-    :type TPR : float
+    :type TPR: float
     :return: DP as float
     """
     try:
@@ -577,7 +577,7 @@ def GI_calc(AUC):
     """
     Calculate Gini index.
 
-    :param AUC: AUC (Area under the ROC curve)
+    :param AUC: Area under the ROC
     :type AUC: float
     :return: Gini index as float
     """
@@ -589,12 +589,12 @@ def GI_calc(AUC):
 
 def lift_calc(PPV, PRE):
     """
-    Calculate lift score.
+    Calculate Lift score.
 
-    :param PPV:  precision or positive predictive value
-    :type PPV : float
+    :param PPV: Positive predictive value (PPV)
+    :type PPV: float
     :param PRE: Prevalence
-    :type PRE : float
+    :type PRE: float
     :return: lift score as float
     """
     try:
@@ -605,12 +605,12 @@ def lift_calc(PPV, PRE):
 
 def AM_calc(TOP, P):
     """
-    Calculate AM (Automatic/Manual).
+    Calculate Automatic/Manual (AM).
 
-    :param TOP: test outcome positive
-    :type TOP : int
-    :param P: condition positive
-    :type P : int
+    :param TOP: number of positives in predict vector
+    :type TOP: int
+    :param P: number of actual positives
+    :type P: int
     :return: AM as int
     """
     try:
@@ -621,14 +621,14 @@ def AM_calc(TOP, P):
 
 def OP_calc(ACC, TPR, TNR):
     """
-    Calculate OP (Optimized precision).
+    Calculate Optimized precision (OP).
 
     :param ACC: accuracy
-    :type ACC : float
+    :type ACC: float
     :param TNR: specificity or true negative rate
-    :type TNR : float
+    :type TNR: float
     :param TPR: sensitivity, recall, hit rate, or true positive rate
-    :type TPR : float
+    :type TPR: float
     :return: OP as float
     """
     try:
@@ -640,14 +640,14 @@ def OP_calc(ACC, TPR, TNR):
 
 def IBA_calc(TPR, TNR, alpha=1):
     """
-    Calculate IBA (Index of balanced accuracy).
+    Calculate Index of balanced accuracy (IBA).
 
     :param TNR: specificity or true negative rate
-    :type TNR : float
+    :type TNR: float
     :param TPR: sensitivity, recall, hit rate, or true positive rate
-    :type TPR : float
-    :param alpha : alpha coefficient
-    :type alpha : float
+    :type TPR: float
+    :param alpha: alpha coefficient
+    :type alpha: float
     :return: IBA as float
     """
     try:
@@ -659,14 +659,14 @@ def IBA_calc(TPR, TNR, alpha=1):
 
 def BCD_calc(TOP, P, AM):
     """
-    Calculate BCD (Bray-Curtis dissimilarity).
+    Calculate Bray-Curtis dissimilarity (BCD).
 
-    :param TOP: test outcome positive
-    :type TOP : dict
-    :param P: condition positive
-    :type P : dict
+    :param TOP: number of positives in predict vector
+    :type TOP: dict
+    :param P: number of actual positives
+    :type P: dict
     :param AM: Automatic/Manual
-    :type AM : int
+    :type AM: int
     :return: BCD as float
     """
     try:
@@ -679,21 +679,21 @@ def BCD_calc(TOP, P, AM):
 
 def class_statistics(TP, TN, FP, FN, classes, table):
     """
-    Return all class statistics.
+    Return All statistics of classes.
 
     :param TP: true positive
-    :type TP : dict
+    :type TP: dict
     :param TN: true negative
-    :type TN : dict
+    :type TN: dict
     :param FP: false positive
-    :type FP : dict
+    :type FP: dict
     :param FN: false negative
-    :type FN : dict
-    :param classes: classes
-    :type classes : list
-    :param table: input matrix
-    :type table : dict
-    :return: result as dict
+    :type FN: dict
+    :param classes: confusion matrix classes
+    :type classes: list
+    :param table: input confusion matrix
+    :type table: dict
+    :return: classes' statistics as dict
     """
     TPR = {}
     TNR = {}
