@@ -9,20 +9,60 @@ from .pycm_ci import kappa_SE_calc, CI_calc, SE_calc
 from .pycm_util import complement
 
 
+def brier_score_calc(
+        classes,
+        prob_vector,
+        actual_vector,
+        sample_weight=None,
+        pos_class=None):
+    """
+    Calculate Brier score.
+
+    :param classes: confusion matrix classes
+    :type classes: list
+    :param prob_vector: probability vector
+    :type prob_vector: python list or numpy array
+    :param actual_vector: actual vector
+    :type actual_vector: python list or numpy array
+    :param sample_weight: sample weights list
+    :type sample_weight: list
+    :param pos_class: positive class name
+    :type pos_class: int/str
+    :return: Brier score as float
+    """
+    try:
+        vector_length = len(actual_vector)
+        if sample_weight is None:
+            sample_weight = [1] * vector_length
+        weight_sum = sum(sample_weight)
+        if pos_class is None:
+            pos_class = max(classes)
+        result = 0
+        for index, item in enumerate(actual_vector):
+            filtered_item = 0
+            if item == pos_class:
+                filtered_item = 1
+            result += (sample_weight[index] / weight_sum) * \
+                (filtered_item - prob_vector[index])**2
+        return result
+    except Exception:
+        return "None"
+
+
 def alpha2_calc(TOP, P, ACC, POP, classes, max_iter=200, epsilon=0.0001):
     """
     Calculate Aickin's alpha.
 
-    :param TOP: test outcome positive
-    :type TOP : dict
-    :param P: condition positive
-    :type P : dict
+    :param TOP: number of positives in predict vector per class
+    :type TOP: dict
+    :param P: number of actual positives per class
+    :type P: dict
     :param ACC: accuracy
-    :type ACC : float
-    :param POP: population
-    :type POP : dict
+    :type ACC: float
+    :param POP: population or total number of samples per class
+    :type POP: dict
     :param classes: confusion matrix classes
-    :type classes : list
+    :type classes: list
     :param max_iter: maximum iteration
     :type max_iter: int
     :param epsilon: difference threshold
@@ -55,14 +95,14 @@ def alpha2_calc(TOP, P, ACC, POP, classes, max_iter=200, epsilon=0.0001):
 
 def alpha_calc(RACC, ACC, POP):
     """
-    Calculate unweighted Krippendorff's alpha.
+    Calculate Unweighted Krippendorff's alpha.
 
     :param RACC: random accuracy
-    :type RACC : float
+    :type RACC: float
     :param ACC: accuracy
-    :type ACC : float
-    :param POP: population
-    :type POP : int
+    :type ACC: float
+    :param POP: population or total number of samples
+    :type POP: int
     :return: unweighted alpha as float
     """
     try:
@@ -76,18 +116,18 @@ def alpha_calc(RACC, ACC, POP):
 
 def weighted_alpha_calc(classes, table, P, TOP, POP, weight):
     """
-    Calculate weighted Krippendorff's alpha.
+    Calculate Weighted Krippendorff's alpha.
 
     :param classes: confusion matrix classes
-    :type classes : list
-    :param table: confusion matrix table
-    :type table : dict
-    :param P: condition positive
-    :type P : dict
-    :param TOP: test outcome positive
-    :type TOP : dict
-    :param POP: population
-    :type POP : dict
+    :type classes: list
+    :param table: input confusion matrix
+    :type table: dict
+    :param P: number of actual positives per class
+    :type P: dict
+    :param TOP: number of positives in predict vector per class
+    :type TOP: dict
+    :param POP: population or total number of samples per class
+    :type POP: dict
     :param weight: weight matrix
     :type weight: dict
     :return: weighted alpha as float
@@ -112,16 +152,16 @@ def weighted_alpha_calc(classes, table, P, TOP, POP, weight):
 
 def B_calc(classes, TP, TOP, P):
     """
-    Calculate B (Bangdiwala's B).
+    Calculate Bangdiwala's B (B).
 
-    :param classes: classes
-    :type classes : list
+    :param classes: confusion matrix classes
+    :type classes: list
     :param TP: true positive
-    :type TP : dict
-    :param TOP: test outcome positive
-    :type TOP : dict
-    :param P: condition positive
-    :type P : dict
+    :type TP: dict
+    :param TOP: number of positives in predict vector per class
+    :type TOP: dict
+    :param P: number of actual positives per class
+    :type P: dict
     :return: B as float
     """
     try:
@@ -138,18 +178,18 @@ def B_calc(classes, TP, TOP, P):
 
 def ARI_calc(classes, table, TOP, P, POP):
     """
-    Calculate ARI (Adjusted Rand index).
+    Calculate Adjusted Rand index (ARI).
 
-    :param classes: classes
-    :type classes : list
-    :param table: input matrix
-    :type table : dict
-    :param TOP: test outcome positive
-    :type TOP : dict
-    :param P: condition positive
-    :type P : dict
-    :param POP: population
-    :type POP : int
+    :param classes: confusion matrix classes
+    :type classes: list
+    :param table: input confusion matrix
+    :type table: dict
+    :param TOP: number of positives in predict vector per class
+    :type TOP: dict
+    :param P: number of actual positives per class
+    :type P: dict
+    :param POP: population or total number of samples
+    :type POP: int
     :return: ARI as float
     """
     try:
@@ -171,12 +211,12 @@ def ARI_calc(classes, table, TOP, P, POP):
 
 def pearson_C_calc(chi_square, POP):
     """
-    Calculate C (Pearson's C).
+    Calculate Pearson's C (C).
 
     :param chi_square: chi squared
-    :type chi_square : float
-    :param POP: population
-    :type POP : int
+    :type chi_square: float
+    :param POP: population or total number of samples
+    :type POP: int
     :return: C as float
     """
     try:
@@ -188,13 +228,13 @@ def pearson_C_calc(chi_square, POP):
 
 def RCI_calc(mutual_information, reference_entropy):
     """
-    Calculate RCI (Relative classifier information).
+    Calculate Relative classifier information (RCI).
 
     :param mutual_information: mutual information
-    :type mutual_information : float
+    :type mutual_information: float
     :param reference_entropy: reference entropy
-    :type reference_entropy : float
-    :return:  RCI as float
+    :type reference_entropy: float
+    :return: RCI as float
     """
     try:
         return mutual_information / reference_entropy
@@ -206,14 +246,14 @@ def AUNP_calc(classes, P, POP, AUC_dict):
     """
     Calculate AUNP.
 
-    :param classes: classes
-    :type classes : list
-    :param P: condition positive
-    :type P : dict
-    :param POP: population
-    :type POP : dict
-    :param AUC_dict: AUC (Area under the ROC curve) for each class
-    :type AUC_dict : dict
+    :param classes: confusion matrix classes
+    :type classes: list
+    :param P: number of actual positives per class
+    :type P: dict
+    :param POP: population or total number of samples per class
+    :type POP: dict
+    :param AUC_dict: Area under the ROC curve (AUC) for each class
+    :type AUC_dict: dict
     :return: AUNP as float
     """
     try:
@@ -227,16 +267,16 @@ def AUNP_calc(classes, P, POP, AUC_dict):
 
 def CBA_calc(classes, table, TOP, P):
     """
-    Calculate CBA (Class balance accuracy).
+    Calculate Class balance accuracy (CBA).
 
-    :param classes: classes
-    :type classes : list
-    :param table: input matrix
-    :type table : dict
-    :param TOP: test outcome positive
-    :type TOP : dict
-    :param P: condition positive
-    :type P : dict
+    :param classes: confusion matrix classes
+    :type classes: list
+    :param table: input confusion matrix
+    :type table: dict
+    :param TOP: number of positives in predict vector per class
+    :type TOP: dict
+    :param P: number of actual positives per class
+    :type P: dict
     :return: CBA as float
     """
     try:
@@ -251,12 +291,12 @@ def CBA_calc(classes, table, TOP, P):
 
 def RR_calc(classes, TOP):
     """
-    Calculate RR (Global performance index).
+    Calculate Global performance index (RR).
 
-    :param classes: classes
-    :type classes : list
-    :param TOP: test outcome positive
-    :type TOP : dict
+    :param classes: confusion matrix classes
+    :type classes: list
+    :param TOP: number of positives in predict vector per class
+    :type TOP: dict
     :return: RR as float
     """
     try:
@@ -271,15 +311,15 @@ def overall_MCC_calc(classes, table, TOP, P):
     """
     Calculate Overall_MCC.
 
-    :param classes: classes
-    :type classes : list
-    :param table: input matrix
-    :type table : dict
-    :param TOP: test outcome positive
-    :type TOP : dict
-    :param P: condition positive
-    :type P : dict
-    :return:  Overall_MCC as float
+    :param classes: confusion matrix classes
+    :type classes: list
+    :param table: input confusion matrix
+    :type table: dict
+    :param TOP: number of positives in predict vector per class
+    :type TOP: dict
+    :param P: number of actual positives per class
+    :type P: dict
+    :return: Overall_MCC as float
     """
     try:
         cov_x_y = 0
@@ -299,19 +339,19 @@ def convex_combination(classes, TP, TOP, P, class_name, modified=False):
     """
     Calculate Overall_CEN coefficient.
 
-    :param classes: classes
-    :type classes : list
+    :param classes: confusion matrix classes
+    :type classes: list
     :param TP: true positive
-    :type TP : dict
-    :param TOP: test outcome positive
-    :type TOP : dict
-    :param P: condition positive
-    :type P : dict
+    :type TP: dict
+    :param TOP: number of positives in predict vector per class
+    :type TOP: dict
+    :param P: number of actual positives per class
+    :type P: dict
     :param class_name: reviewed class name
-    :type class_name : any valid type
-    :param modified : modified mode flag
-    :type modified : bool
-    :return: coefficient as float
+    :type class_name: any valid type
+    :param modified: modified mode flag
+    :type modified: bool
+    :return: Overall_CEN coefficient as float
     """
     try:
         class_number = len(classes)
@@ -334,18 +374,18 @@ def overall_CEN_calc(classes, TP, TOP, P, CEN_dict, modified=False):
     """
     Calculate Overall_CEN (Overall confusion entropy).
 
-    :param classes: classes
-    :type classes : list
+    :param classes: confusion matrix classes
+    :type classes: list
     :param TP: true positive
-    :type TP : dict
-    :param TOP: test outcome positive
-    :type TOP : dict
-    :param P: condition positive
-    :type P : dict
+    :type TP: dict
+    :param TOP: number of positives in predict vector per class
+    :type TOP: dict
+    :param P: number of actual positives per class
+    :type P: dict
     :param CEN_dict: CEN dictionary for each class
-    :type CEN_dict : dict
-    :param modified : modified mode flag
-    :type modified : bool
+    :type CEN_dict: dict
+    :param modified: modified mode flag
+    :type modified: bool
     :return: Overall_CEN(MCEN) as float
     """
     try:
@@ -360,13 +400,13 @@ def overall_CEN_calc(classes, TP, TOP, P, CEN_dict, modified=False):
 
 def ncr(n, r):
     """
-    Calculate n choose r.
+    Calculate the combination of n and r.
 
     :param n: n
-    :type n : int
+    :type n: int
     :param r: r
     :type r :int
-    :return: n choose r as int
+    :return: the combination of n and r as int
     """
     if r > n:
         return 0
@@ -381,11 +421,11 @@ def p_value_calc(TP, POP, NIR):
     Calculate p_value.
 
     :param TP: true positive
-    :type TP : dict
-    :param POP: population
-    :type POP : int
+    :type TP: dict
+    :param POP: population or total number of samples
+    :type POP: int
     :param NIR: no information rate
-    :type NIR : float
+    :type NIR: float
     :return: p_value as float
     """
     try:
@@ -402,12 +442,12 @@ def p_value_calc(TP, POP, NIR):
 
 def NIR_calc(P, POP):
     """
-    Calculate NIR (No information rate).
+    Calculate No information rate (NIR).
 
-    :param P: condition positive
-    :type P : dict
-    :param POP: population
-    :type POP : int
+    :param P: number of actual positives per class
+    :type P: dict
+    :param POP: population or total number of samples
+    :type POP: int
     :return: NIR as float
     """
     try:
@@ -420,13 +460,13 @@ def NIR_calc(P, POP):
 
 def hamming_calc(TP, POP):
     """
-    Calculate hamming loss.
+    Calculate Hamming loss.
 
     :param TP: true positive
-    :type TP : dict
-    :param POP: population
-    :type POP : int
-    :return: hamming loss as float
+    :type TP: dict
+    :param POP: population or total number of samples
+    :type POP: int
+    :return: Hamming loss as float
     """
     try:
         length = POP
@@ -437,13 +477,13 @@ def hamming_calc(TP, POP):
 
 def zero_one_loss_calc(TP, POP):
     """
-    Calculate zero-one loss.
+    Calculate Zero-one loss.
 
     :param TP: true Positive
-    :type TP : dict
-    :param POP: population
-    :type POP : int
-    :return: zero_one loss as integer
+    :type TP: dict
+    :param POP: population or total number of samples
+    :type POP: int
+    :return: Zero-one loss as integer
     """
     try:
         length = POP
@@ -454,13 +494,13 @@ def zero_one_loss_calc(TP, POP):
 
 def entropy_calc(item, POP):
     """
-    Calculate reference and response likelihood.
+    Calculate Reference and Response likelihood.
 
-    :param item : TOP or P
-    :type item : dict
-    :param POP: population
-    :type POP : dict
-    :return: reference or response likelihood as float
+    :param item: number of positives in actual or predict vector per class (P or TOP)
+    :type item: dict
+    :param POP: population or total number of samples per class
+    :type POP: dict
+    :return: Reference or Response likelihood as float
     """
     try:
         result = 0
@@ -475,21 +515,21 @@ def entropy_calc(item, POP):
 
 def weighted_kappa_calc(classes, table, P, TOP, POP, weight):
     """
-    Calculate weighted kappa.
+    Calculate Weighted kappa.
 
     :param classes: confusion matrix classes
-    :type classes : list
-    :param table: confusion matrix table
-    :type table : dict
-    :param P: condition positive
-    :type P : dict
-    :param TOP: test outcome positive
-    :type TOP : dict
-    :param POP: population
-    :type POP : dict
+    :type classes: list
+    :param table: input confusion matrix
+    :type table: dict
+    :param P: number of actual positives per class
+    :type P: dict
+    :param TOP: number of positives in predict vector per class
+    :type TOP: dict
+    :param POP: population or total number of samples per class
+    :type POP: dict
     :param weight: weight matrix
     :type weight: dict
-    :return: weighted kappa as float
+    :return: Weighted kappa as float
     """
     p_e = 0
     p_a = 0
@@ -508,11 +548,11 @@ def weighted_kappa_calc(classes, table, P, TOP, POP, weight):
 
 def kappa_no_prevalence_calc(overall_accuracy):
     """
-    Calculate kappa no prevalence.
+    Calculate Kappa no prevalence.
 
     :param overall_accuracy: overall accuracy
-    :type overall_accuracy : float
-    :return: kappa no prevalence as float
+    :type overall_accuracy: float
+    :return: Kappa no prevalence as float
     """
     try:
         result = 2 * overall_accuracy - 1
@@ -523,14 +563,14 @@ def kappa_no_prevalence_calc(overall_accuracy):
 
 def cross_entropy_calc(TOP, P, POP):
     """
-    Calculate cross entropy.
+    Calculate Cross entropy.
 
-    :param TOP: test outcome positive
-    :type TOP : dict
-    :param P: condition positive
-    :type P : dict
-    :param POP: population
-    :type POP : dict
+    :param TOP: number of positives in predict vector per class
+    :type TOP: dict
+    :param P: number of actual positives per class
+    :type P: dict
+    :param POP: population or total number of samples per class
+    :type POP: dict
     :return: cross entropy as float
     """
     try:
@@ -548,14 +588,14 @@ def cross_entropy_calc(TOP, P, POP):
 
 def joint_entropy_calc(classes, table, POP):
     """
-    Calculate joint entropy.
+    Calculate Joint entropy.
 
     :param classes: confusion matrix classes
-    :type classes : list
-    :param table: confusion matrix table
-    :type table : dict
-    :param POP: population
-    :type POP : dict
+    :type classes: list
+    :param table: input confusion matrix
+    :type table: dict
+    :param POP: population or total number of samples per class
+    :type POP: dict
     :return: joint entropy as float
     """
     try:
@@ -572,16 +612,16 @@ def joint_entropy_calc(classes, table, POP):
 
 def conditional_entropy_calc(classes, table, P, POP):
     """
-    Calculate conditional entropy.
+    Calculate Conditional entropy.
 
     :param classes: confusion matrix classes
-    :type classes : list
-    :param table: confusion matrix table
-    :type table : dict
-    :param P: condition positive
-    :type P : dict
-    :param POP: population
-    :type POP : dict
+    :type classes: list
+    :param table: input confusion matrix
+    :type table: dict
+    :param P: number of actual positives per class
+    :type P: dict
+    :param POP: population or total number of samples per class
+    :type POP: dict
     :return: conditional entropy as float
     """
     try:
@@ -602,12 +642,12 @@ def conditional_entropy_calc(classes, table, P, POP):
 
 def mutual_information_calc(response_entropy, conditional_entropy):
     """
-    Calculate mutual information.
+    Calculate Mutual information.
 
-    :param response_entropy:  response entropy
-    :type response_entropy : float
-    :param conditional_entropy:  conditional entropy
-    :type conditional_entropy : float
+    :param response_entropy: response entropy
+    :type response_entropy: float
+    :param conditional_entropy: conditional entropy
+    :type conditional_entropy: float
     :return: mutual information as float
     """
     try:
@@ -620,13 +660,13 @@ def kl_divergence_calc(P, TOP, POP):
     """
     Calculate Kullback-Liebler (KL) divergence.
 
-    :param P: condition positive
-    :type P : dict
-    :param TOP: test outcome positive
-    :type TOP : dict
-    :param POP: population
-    :type POP : dict
-    :return: Kullback-Liebler (KL) divergence as float
+    :param P: number of actual positives per class
+    :type P: dict
+    :param TOP: number of positives in predict vector per class
+    :type TOP: dict
+    :param POP: population or total number of samples per class
+    :type POP: dict
+    :return: KL divergence as float
     """
     try:
         result = 0
@@ -645,13 +685,13 @@ def lambda_B_calc(classes, table, TOP, POP):
     Calculate Goodman and Kruskal's lambda B.
 
     :param classes: confusion matrix classes
-    :type classes : list
-    :param table: confusion matrix table
-    :type table : dict
-    :param TOP: test outcome positive
-    :type TOP : dict
-    :param POP: population
-    :type POP : int
+    :type classes: list
+    :param table: input confusion matrix
+    :type table: dict
+    :param TOP: number of positives in predict vector per class
+    :type TOP: dict
+    :param POP: population or total number of samples
+    :type POP: int
     :return: Goodman and Kruskal's lambda B as float
     """
     try:
@@ -671,13 +711,13 @@ def lambda_A_calc(classes, table, P, POP):
     Calculate Goodman and Kruskal's lambda A.
 
     :param classes: confusion matrix classes
-    :type classes : list
-    :param table: confusion matrix table
-    :type table : dict
-    :param P: condition positive
-    :type P : dict
-    :param POP: population
-    :type POP : int
+    :type classes: list
+    :param table: input confusion matrix
+    :type table: dict
+    :param P: number of actual positives per class
+    :type P: dict
+    :param POP: population or total number of samples
+    :type POP: int
     :return: Goodman and Kruskal's lambda A as float
     """
     try:
@@ -697,18 +737,18 @@ def lambda_A_calc(classes, table, P, POP):
 
 def chi_square_calc(classes, table, TOP, P, POP):
     """
-    Calculate chi-squared.
+    Calculate Chi-squared.
 
     :param classes: confusion matrix classes
-    :type classes : list
-    :param table: confusion matrix table
-    :type table : dict
-    :param TOP: test outcome positive
-    :type TOP : dict
-    :param P: condition positive
-    :type P : dict
-    :param POP: population
-    :type POP : dict
+    :type classes: list
+    :param table: input confusion matrix
+    :type table: dict
+    :param TOP: number of positives in predict vector per class
+    :type TOP: dict
+    :param P: number of actual positives per class
+    :type P: dict
+    :param POP: population or total number of samples per class
+    :type POP: dict
     :return: chi-squared as float
     """
     try:
@@ -724,12 +764,12 @@ def chi_square_calc(classes, table, TOP, P, POP):
 
 def phi_square_calc(chi_square, POP):
     """
-    Calculate phi-squared.
+    Calculate Phi-squared.
 
     :param chi_square: chi squared
-    :type chi_square : float
-    :param POP: population
-    :type POP : int
+    :type chi_square: float
+    :param POP: population or total number of samples
+    :type POP: int
     :return: phi_squared as float
     """
     try:
@@ -743,9 +783,9 @@ def cramers_V_calc(phi_square, classes):
     Calculate Cramer's V.
 
     :param phi_square: phi_squared
-    :type phi_square : float
+    :type phi_square: float
     :param classes: confusion matrix classes
-    :type classes : list
+    :type classes: list
     :return: Cramer's V as float
     """
     try:
@@ -756,10 +796,10 @@ def cramers_V_calc(phi_square, classes):
 
 def DF_calc(classes):
     """
-    Calculate chi-squared degree of freedom.
+    Calculate Chi-squared degree of freedom (DF).
 
     :param classes: confusion matrix classes
-    :type classes : list
+    :type classes: list
     :return: DF as int
     """
     try:
@@ -770,12 +810,12 @@ def DF_calc(classes):
 
 def reliability_calc(RACC, ACC):
     """
-    Calculate reliability.
+    Calculate Reliability.
 
     :param RACC: random accuracy
-    :type RACC : float
+    :type RACC: float
     :param ACC: accuracy
-    :type ACC : float
+    :type ACC: float
     :return: reliability as float
     """
     try:
@@ -787,13 +827,13 @@ def reliability_calc(RACC, ACC):
 
 def micro_calc(item1, item2):
     """
-    Calculate PPV,TPR,TNR,FNR,FPR,F1 micro.
+    Calculate TPR, TNR, PPV, FNR, FPR, or F1 micro.
 
     :param item1: item1 in micro averaging
     :type item1:dict
     :param item2: item2 in micro averaging
-    :type item2 : dict
-    :return: PPV,TPR,TNR,FNR,FPR,F1 micro as float
+    :type item2: dict
+    :return: PPV, TPR, TNR, FNR, FPR, or F1 micro as float
     """
     try:
         item1_sum = sum(item1.values())
@@ -807,7 +847,7 @@ def macro_calc(item):
     """
     Calculate PPV_Macro and TPR_Macro.
 
-    :param item: PPV or TPR
+    :param item: True positive rate (TPR) or Positive predictive value (PPV)
     :type item:dict
     :return: PPV_Macro or TPR_Macro as float
     """
@@ -821,13 +861,13 @@ def macro_calc(item):
 
 def PC_AC1_calc(P, TOP, POP):
     """
-    Calculate percent chance agreement for Gwet's AC1.
+    Calculate Percent chance agreement for Gwet's AC1.
 
-    :param P: condition positive
-    :type P : dict
-    :param TOP: test outcome positive
-    :type TOP : dict
-    :param POP: population
+    :param P: number of actual positives per class
+    :type P: dict
+    :param TOP: number of positives in predict vector per class
+    :type TOP: dict
+    :param POP: population or total number of samples per class
     :type POP:dict
     :return: percent chance agreement as float
     """
@@ -845,10 +885,10 @@ def PC_AC1_calc(P, TOP, POP):
 
 def PC_S_calc(classes):
     """
-    Calculate percent chance agreement for Bennett-et-al.'s-S-score.
+    Calculate Percent chance agreement for Bennett-et-al.'s-S-score.
 
     :param classes: confusion matrix classes
-    :type classes : list
+    :type classes: list
     :return: percent chance agreement as float
     """
     try:
@@ -859,11 +899,11 @@ def PC_S_calc(classes):
 
 def overall_jaccard_index_calc(jaccard_list):
     """
-    Calculate overall jaccard index.
+    Calculate Overall Jaccard index.
 
-    :param jaccard_list : list of jaccard index for each class
-    :type jaccard_list : list
-    :return: (jaccard_sum , jaccard_mean) as tuple
+    :param jaccard_list: list of Jaccard index for each class
+    :type jaccard_list: list
+    :return: (Jaccard_sum, Jaccard_mean) as tuple
     """
     try:
         jaccard_sum = sum(jaccard_list)
@@ -875,11 +915,11 @@ def overall_jaccard_index_calc(jaccard_list):
 
 def overall_accuracy_calc(TP, POP):
     """
-    Calculate overall accuracy.
+    Calculate Overall accuracy.
 
     :param TP: true positive
-    :type TP : dict
-    :param POP: population
+    :type TP: dict
+    :param POP: population or total number of samples
     :type POP:int
     :return: overall_accuracy as float
     """
@@ -892,10 +932,10 @@ def overall_accuracy_calc(TP, POP):
 
 def overall_random_accuracy_calc(item):
     """
-    Calculate overall random accuracy.
+    Calculate Overall random accuracy.
 
-    :param item: RACC or RACCU
-    :type item : dict
+    :param item: random accuracy or random accuracy unbiased
+    :type item: dict
     :return: overall random accuracy as float
     """
     try:
@@ -906,7 +946,7 @@ def overall_random_accuracy_calc(item):
 
 def overall_statistics(**kwargs):
     """
-    Return overall statistics.
+    Return Overall statistics.
 
     :param kwargs: inputs
     :type kwargs: dict
